import {Component, ComponentInterface, Prop, h} from '@stencil/core';

@Component({
  tag: 'hy-cta-link-button',
  styleUrl: 'cta-link-button.scss',
  shadow: true
})
export class CtaLinkButton implements ComponentInterface {
  /**
   * deprecated, use slot
   */
  @Prop() linkContent: string = '';
  @Prop() url?: string;
  @Prop() scLabel?: string;
  @Prop() isExternal: boolean = false;

  render() {
    const containerClassAttributes = ['hy-cta-link-button-container'].join(' ');
    const classAttributes = ['hy-cta-link-button'];

    const textClassAttributes = ['hy-cta-link-button__text'].join(' ');
    const iconClassAttributes = ['hy-cta-link-button__link-icon'].join(' ');

    const target = this.isExternal ? '_blank' : '_self';

    return (
      <span class={containerClassAttributes}>
        <a aria-label={this.scLabel} class={classAttributes.join(' ')} href={this.url} target={target}>
          <span class={textClassAttributes}>{this.linkContent.length === 0 ? <slot /> : this.linkContent}</span>
          <span class={iconClassAttributes}>
            <hy-icon icon={'hy-icon-arrow-right'} size={48} />
          </span>
        </a>
      </span>
    );
  }
}
